awful.hooks.focus.register(function (c)
    if not awful.client.ismarked(c) then
        c.border_color = beautiful.border_focus
        local cls = c.class
        local inst = c.instance
        if apptags[inst] then
             local target = apptags[inst]
             if target.opacity_focused then
                 c.opacity = target.opacity_focused
             end
         end
    end
end)

-- Hook function to execute when unfocusing a client.
awful.hooks.unfocus.register(function (c)
    if not awful.client.ismarked(c) then
        c.border_color = beautiful.border_normal
        local cls = c.class
        local inst = c.instance
        if apptags[inst] then
             local target = apptags[inst]
             if target.opacity_unfocused then
                 c.opacity = target.opacity_unfocused
             end
        end
    end
end)

-- Hook function to execute when marking a client
function hook_marked(c)
    c.border_color = beautiful.border_marked
end

-- Hook function to execute when unmarking a client
function hook_unmarked(c)
    c.border_color = beautiful.border_focus
end

-- Hook function to execute when the mouse is over a client.
-- function hook_mouseover(c)
--     -- Sloppy focus, but disabled for magnifier layout
--     if awful.layout.get(c.screen) ~= "magnifier" then
--         client.focus = c
--     end
-- end

-- Hook function to execute when a new client appears.
awful.hooks.manage.register(function (c,startup)
    -- Check if the application should be floating.
    local cls = c.class
    local inst = c.instance
    local name = c.name

    -- Check application->screen/tag mappings.
    local target
    local tag_index


    if use_titlebar then
        -- Add a titlebar
        awful.titlebar.add(c, { modkey = modkey })
    end

    if apptags[cls] then
        target = apptags[cls]
    elseif apptags[inst] then
        target = apptags[inst]
    elseif apptags[name] then
        target = apptags[name]
    end
    if (cls=="feh") and (string.find(name,"http")) then
        awful.client.floating.set(c,true)
        awful.titlebar.remove(c)
    elseif (string.find(name,"Task Coach")) then
        awful.client.movetotag(tags[get_tag_by_name("todo")])
    elseif target then
        tag_index = get_tag_by_name(target.tag)

        if tag_index > 0 then
            awful.client.movetotag(tags[tag_index], c)
        end

        if target.slave then
            if target.slave > 0 then
                awful.client.setslave(c)
            end
        end

        if target.title then
            c.name = target.title
        end 

    elseif c.type == "dialog" then
        awful.titlebar.add(c, { modkey = modkey })
    end

    if floatapps[cls] or floatapps[inst] then
        c.floating = floatapps[inst]
    end

--    if titleapps[cls] or titleapps[inst] or floatapps[cls] or floatapps[inst] then
--        awful.titlebar.add(c, { modkey = modkey })
        -- mytitlebar = titlebar( {position = "top"} )
        -- mytitlebartitle = widget( { type="textbox", name = "mytitlebartitle" } )
        -- mytitlebar:widgets({mytitlebartitle})
        -- mytitlebartitle.text = c.name
        -- c.titlebar = mytitlebar
--    end

     c:buttons({
        button({ }, 1, function (c) client.focus = c; c:raise() end),
        button({ modkey }, 1, function (c) c:mouse_move() end),
        button({ modkey }, 3, function (c) c:mouse_resize() end),
    })
    c.border_width = beautiful.border_width
    c.border_color = beautiful.border_normal
    client.focus = c
       

    -- Honor size hints
    c.size_hints_honor = true

    c:keys(clientkeys)
    c:buttons({
        button({ }, 1, function (c) client.focus = c; c:raise() end),
        button({ modkey }, 1, awful.mouse.client.move),
        button({ modkey }, 3, awful.mouse.client.resize)
    })
end)

-- Hook function to execute when arranging the screen
-- (tag switch, new client, etc)
function hook_arrange(screen)
    local layout = awful.layout.getname(awful.layout.get(screen))

    if layout then
            mylayoutbox.image = image("/usr/share/awesome/themes/default/layouts/" .. layout .. "w.png")
    end

    -- If no window has focus, give focus to the latest in history
    if not client.focus then
        local c = awful.client.focus.history.get(screen, 0)
        if c then client.focus = c end
    end

    -- Uncomment if you want mouse warping
    --[[
    local sel = client.focus
    if sel then
        local c_c = sel:coords()
        local m_c = mouse.coords()

        if m_c.x < c_c.x or m_c.x >= c_c.x + c_c.width or
            m_c.y < c_c.y or m_c.y >= c_c.y + c_c.height then
            if table.maxn(m_c.buttons) == 0 then
                mouse.coords({ x = c_c.x + 5, y = c_c.y + 5})
            end
        end
    end
    ]]
end

-- Hook called every second
-- function hook_timer ()
--     -- For unix time_t lovers
--     -- mytextbox.text = " " .. os.time() .. " time_t "
--     -- Otherwise use:
--     tb_date.text = " " .. os.date("%Y. %b. %d, %A") .. " "
--     tb_time.text = " ".. os.date("%H:%M:%S") .. " "
--     pb_uptime:bar_data_add("hour","50")
-- end

-- sensors
sensors_dir = "/sys/devices/platform/it87.656/"
sensor_temp = {
    { file = sensors_dir .. "temp1_input", tb = tb_temp_mb  },
    { file = sensors_dir .. "temp2_input", tb = tb_temp_cpu },
    { file = sensors_dir .. "temp3_input", tb = tb_temp_case},
}

sensor_fan = {
    { file = sensors_dir .. "fan1_input",  tb = tb_fan_cpu  },
    { file = sensors_dir .. "fan2_input",  tb = tb_fan_case },
}

function hook_sensors ()

    local i, val, f, color

    for i=1,#sensor_temp do
        f=io.open(sensor_temp[i].file,"r")
        val = f:read("*number")
        val = val/1000
        if (val>47) then color = "#FF0000"
        elseif (val>40) then color = "yellow"
        elseif (val>35) then color = "green"
        else color = "white"
        end
--        sensor_temp[i].tb.bg = color
        sensor_temp[i].tb.text = '<span color="' .. color .. '">' .. val .. "°C" .. "</span>"
        f:close()
    end

    for i=1,#sensor_fan do
        f=io.open(sensor_fan[i].file,"r")
        val = f:read("*number")
        if (val>3200) then color = "red"
        elseif (val>2600) then color = "yellow"
        elseif (val>2200) then color = "green"
        else color = "white"
        end
        sensor_fan[i].tb.text = '<span color="' .. color .. '">' .. val .. "</span>"
        f:close()
    end

end


-- mpd
-- lol = luampd:new { host = "localhost" , port = 6600, debug = false }
-- mpd_playing = 0
moc_playing = 0

-- function hook_mpd_update ()
--     function song_output(current_song, status)
--         cur_time = string.sub(status.time,1,string.find(status.time,":")-1);
--         tot_time = string.sub(status.time,string.find(status.time,":")+1,-1);
--         cur_min = math.floor(cur_time/60)
--         cur_sec = cur_time-cur_min*60
--         tot_min = math.floor(tot_time/60)
--         tot_sec = tot_time-tot_min*60
-- 
--         if current_song.artist then
--             song_str = current_song.artist 
--         else 
--             song_str = "unknown artist"
--         end
-- 
--         if current_song.title then
--             song_str = "<span color='white'>" .. song_str .. "</span> - <span color='white'>" .. current_song.title .. "</span>"
--         else 
--             song_str = song_str .. " - unknown title"
--         end
-- 
--         if not current_song.title and not current_song.artist then
--             song_str = string.gsub(current_song.file,"(.*/)","")
--         end
-- 
--         return song_str .. " (" ..
--             cur_min .. ":" .. string.format("%02d",cur_sec) .. "/" .. 
--             tot_min .. ":" .. string.format("%02d",tot_sec) .. ")"
--     end
-- 
--     local status = lol:status()
--     if not status then
--         lol = luampd:new { host = "localhost" , port = 6600, debug = false }
--         status = lol:status()
--     end
-- 
-- 
--     if status.state == "play" then
--         local cs = lol:currentsong()
--         mpd_playing = 1
--         tb_mpd.text = "<span color='lightblue'>MPD: </span>" .. song_output(cs,status)
--     else if status.state == "stop" then
--         mpd_playing = 0
-- --        don't need because moc will print this message
-- --        tb_mpd.text = "-- not playing --"
--     else if status.state == "pause" then
--         local cs = lol:currentsong()
--         tb_mpd.text = "MPD: [[ " .. song_output(cs,status) .. " ]]"
--         ib_control_play.image = image(icon_path_control .. "control_pause.png")
--     else
--         ib_control_play.image = image(icon_path_control .. "control_play.png")
--     end end end
-- end

-- moc
MOC_MAX_CHAR = 60
Scroller = 0

function moc_format(str,format)
    if (format=="artist") then
        return "<span color='white'>" .. str .. "</span>"
    elseif (format=="title") then
        return "<span color='white'>" .. str .. "</span>"
    end
end

function hook_moc()
        local moc_file = io.popen("mocp -i")
        if moc_file then
            moc_info = awful.util.escape(moc_file:read("*all"))
            moc_file:close()
            local moc_state = string.match(moc_info, "State: %a*")
            if moc_state then
                moc_state = string.gsub(string.match(moc_info, "State: %a*"),"State: ","")
            else
                moc_state = ""
            end
            if moc_state == "PLAY" or moc_state == "PAUSE" then
                moc_playing = 1
                moc_artist = string.gsub(string.match(moc_info, "Artist: %C*"), "Artist: ","")
                moc_title = string.gsub(string.match(moc_info, "SongTitle: %C*"), "SongTitle: ","")
                moc_curtime = string.gsub(string.match(moc_info, "CurrentTime: %d*:%d*"), "CurrentTime: ","")
                moc_totaltime = string.gsub(string.match(moc_info, "TotalTime: %d*:%d*"), "TotalTime: ","")
                if moc_artist == "" and moc_title == "" then
                    local moc_filestr = string.match(moc_info,"File: %C*")
                    moc_string = "<span color='white'>" .. 
                        string.gsub(string.gsub(moc_filestr,"File: %C*/",""),"%.[mM][pP]3$","") .. 
                        "</span>"
                else
                    if moc_artist == "" then 
                        moc_artist = "unknown artist" 
                    end
                    if moc_title == "" then 
                        moc_title = "unknown title" 
                    end
                    moc_string = "<span color='white'>" .. moc_artist .. "</span> - <span color='white'>" .. moc_title .. "</span>"
                end
                moc_string = moc_string .. " (" .. moc_curtime .. "/" .. moc_totaltime .. ")"
                if moc_state == "PAUSE" then 
                    moc_string = " <span color='red'>[[</span> " .. moc_string .. " <span color='red'>]]</span>"
                    ib_control_play.image = image(icon_path_control .. "control_play.png")
                else
                    ib_control_play.image = image(icon_path_control .. "control_pause.png")
                end
            else
                moc_string = "-- not playing --"
                moc_playing = 0
            end
        else 
            moc_string = "-- not playing --"
            moc_playing = 0
        end
--        if ( moc_artist:len()+moc_title:len()+3 > MOC_MAX_CHAR ) then
--            tb_mpd.text = string.sub(moc_string,Scroller,Scroller+MOC_MAX_CHAR)
--            Scroller = Scroller + 1
--        else
--            Scroller = 0
            tb_mpd.text = moc_string
--        end
end
    

function media_buttons(action)
    if (action=="play") then
        os.execute("mocp -G")
    elseif (action=="prev") then
        os.execute("mocp -r")
    elseif (action=="next") then
        os.execute("mocp -f")
    elseif (action=="stop") then
        os.execute("mocp -s")
    elseif (action=="rew") then
        os.execute("mocp -k -5")
    elseif (action=="ff") then
        os.execute("mocp -k 5")
    end
end

-- uptime
function hook_uptime ()
    local f, val, hour, min
    f = io.open("/proc/uptime","r")
    val = f:read("*number")
    hour = math.floor(val/3600)
    val = val-hour*3600
    min = math.floor(val/60)
    val = math.floor(val-min*60)
    tb_uptime.text = '<span background="#130d1c"><span color="lightblue"> Uptime: </span><span color="white">' .. hour .. ":" .. string.format("%02d",min) .. ":" .. string.format("%02d",val) .. "</span></span>"
    f:close()
end

function hook_clawsmail ()
    local cm_file = io.popen("claws-mail --status INBOX")
    if cm_file then
        cm_str = cm_file:read("*all")
        _,_,unread = string.find(cm_str,"%d+.(%d+).%d+")
        tb_gmail.text = unread
        cm_file:close()
    end
end

function hook_rss ()
    local db = sqlite3.open(newsbeuter_db)
    if db then
        local row = db:first_irow("SELECT COUNT(*) FROM rss_item WHERE unread=1;")
        if row then 
            tb_rss.text = row[1]
        end
        db:close()
    end
end

base_url = "http://tv.animare.hu/rssfeed.aspx?tartalom=aktualistvmusor&tvcsatorna="

table_rss = {
    { title = "AXN" ,       url = 27 },
    { title = "Comedy Central", url = 125 },
    { title = "Cool TV" ,   url = 28 },
    { title = "Discovery",  url = 32 },
    { title = "Duna TV",    url = 6  },
    { title = "Film+",      url = 25 },
    { title = "m2",         url = 2  },
    { title = "mtv",        url = 1  },
    { title = "MTV",        url = 48 },
    { title = "National Geographic", url = 13 },
    { title = "RTL Klub",   url = 5  },
    { title = "TV2",        url = 3  },
    { title = "TV6",        url = 111},
    { title = "Viasat 3",   url = 16 },
}

loaded_rss = {}
for i = 1, #table_rss do
    loaded_rss[i] = {}
    for j = 1, 5 do
        loaded_rss[i].time = {}
        loaded_rss[i].title = {}
    end
end


function hook_fetch_rss ()
    for i = 1, #table_rss do

        local f = io.open(os.getenv("HOME") .. "/tmp/tv" .. table_rss[i].url .. ".txt","r");

        for j=1, 5 do
            local tmpstr = f:read()
            if tmpstr then
                loaded_rss[i].time[j] = string.sub(tmpstr, string.find(tmpstr,"%d%d:%d%d"))
                loaded_rss[i].title[j] = awful.util.escape(string.gsub(tmpstr,"%d%d:%d%d ",""))
--            else
--                loaded_rss[i].time[j] = ""
--                loaded_rss[i].title[j] = ""
            end
        end

        f:close()

    end
end


tvmusor_index = 1

function hook_tvmusor ()
    ib_musor.image = image(os.getenv("HOME") .. "/awesome-resources/icons/tv/" .. table_rss[tvmusor_index].url .. ".gif")
    if loaded_rss[tvmusor_index].time[1] then
        tb_musor.text = "  <span color='lightblue'>" .. loaded_rss[tvmusor_index].time[1] .. " </span>" .. 
            "<span color='white'>" .. loaded_rss[tvmusor_index].title[1] .. "</span>" ..
            "<span color='lightgray'> (" .. loaded_rss[tvmusor_index].time[2] .. " " .. loaded_rss[tvmusor_index].title[2] .. ")</span>"
    end
    tvmusor_index = tvmusor_index + 1
    if (tvmusor_index > #table_rss) then
        tvmusor_index = 1
    end
end

local show = 0
local notifies = {}
local musor_colors = {
    "yellow","white","lightgreen","red","brown"
}

function hook_all_tvmusor ()
    if (show==0) then
        show = 1
        for j=1, #table_rss do
            local msg = ""
            for i=1, 5 do
                if loaded_rss[j].time[i] then
                    msg = msg .. "<span color='lightblue'>" .. loaded_rss[j].time[i] .. "</span> " 
                    msg = msg .. "<span color='" .. musor_colors[i] .. "'>" .. loaded_rss[j].title[i] .. "</span>"
                end
                if (i<5) then
                    msg = msg .. "\n"
                end
            end
            if j<8 then
                pos = "top_left"
            else 
                pos = "top_right"
            end
            notifies[j] = naughty.notify({ 
                text = msg, 
                title = table_rss[j].title, 
                timeout = 0, 
                position = pos,
                width = 480,
                bg = "#000000aa",
                border_color = "#aa0000",
                border_width = 7,
                run = function() naughty.destroy(notifies[j]) notifies[j] = nil end
            })
        end
    else
        show = 0
        for j=1, #table_rss do
            if notifies[j] then
                naughty.destroy(notifies[j])
            end
        end
    end
end

TC_SUBJECT="subject"
TC_ID="id"
TC_TASKLIST="categorizables"
TC_COLOR="color"
TC_PRIOR="priority"

tasks = {}
tc_db_tasks = {}

function hook_taskcoach_reload()
    local nrtasks=1
    f = io.open(taskcoach_db,"r")
    if f then
        s = f:read("*all")
        f:close()
    end

    i = string.find(s,"<category")
    tc_tasks = string.sub(s,1,i-1) .. "</tasks>"
    tc_cat = string.sub(s,1,string.find(s,"<tasks>")-1) .. "<tasks>" .. string.sub(s,i,string.find(s,"<syncml")-1) .. "</tasks>"

    tc_db_tasks = etree.fromstring(tc_tasks)
    for i=1,#tc_db_tasks do 
        if not tc_db_tasks[i].attr["completiondate"] then
            tasks[nrtasks] = {}
            tasks[nrtasks].subject = tc_db_tasks[i].attr[TC_SUBJECT]
            tasks[nrtasks].id = tc_db_tasks[i].attr[TC_ID]
            if tc_db_tasks[i].attr[TC_PRIOR] then
                tasks[nrtasks].priority = tonumber(tc_db_tasks[i].attr[TC_PRIOR])
            else
                tasks[nrtasks].priority = 0
            end
            tasks[nrtasks].category = {}
            nrtasks = nrtasks + 1
        end
    end

    tc_db_cat = etree.fromstring(tc_cat)
    taskcoach_walk(tc_db_cat,"","")

    table.sort(tasks,function(a,b) return a.priority > b.priority end)

end

function hook_taskcoach_print()
    tb_todo.text = #tasks
end

function taskcoach_walk(where,cat,color)
    if where then
        local i
        for i=1,#where do
            local tmp = cat
            local tmp_color
            if where[i] then if where[i].attr then 
                if where[i].attr[TC_COLOR] then
                    tmp_color = where[i].attr[TC_COLOR]
                else
                    tmp_color = color
                end
                if where[i].attr[TC_SUBJECT] then
                    if tmp ~= "" then 
                        tmp = tmp .. "/"
                    else
                        tmp = "("
                    end
                    tmp = tmp ..  where[i].attr[TC_SUBJECT]
                    for j=1,#tasks do
                        if where[i].attr[TC_TASKLIST] then
                            k = string.find(where[i].attr[TC_TASKLIST],tasks[j].id)
                            if k then
                                tasks[j].category[#tasks[j].category+1]=tmp .. ")"
                                local color_dec = {}
                                local TMP_COLOR = tmp_color
                                for l=1,3 do
                                    color_b, color_e = string.find(TMP_COLOR,"%d+,")
                                    color_dec[l] = string.sub(TMP_COLOR,color_b,color_e-1)
                                    TMP_COLOR = string.sub(TMP_COLOR,color_e+1,-1)
                                end
                                tasks[j].color = string.format("#%.2X%.2X%.2X",color_dec[1],color_dec[2],color_dec[3])
                            end
                        end
                    end
                end
            end end
            taskcoach_walk(where[i],tmp,tmp_color)
        end
    end
end

notify_tasks = nil
function hook_print_tasks ()
    if not notify_tasks then 
        local msg = ""
        for i=1,#tasks do
            tmp = tasks[i].subject
            for j=1,#tasks[i].category do
                if string.len(msg) > 0 then msg = msg .. "\n" end
                if tasks[i].priority then msg = msg .. tasks[i].priority .. " " end
                msg = msg .. "<span color='" .. tasks[i].color .. "'>"
                msg = msg .. tasks[i].subject .. " " ..  tasks[i].category[j] .. "</span>"
            end
        end
        notify_tasks = naughty.notify({ 
            text = msg, 
            title = "Teendők",
            timeout = 0, 
            position = pos,
            width = 600,
            bg = "#000000cc",
            border_color = "#aa0000",
            border_width = 7,
            run = function() naughty.destroy(notify_tasks) notify_tasks = nil end
        })
    else
        if notify_tasks then 
            naughty.destroy(notify_tasks)
            notify_tasks = nil
        end
    end
end

hook_taskcoach_reload()
