-- awesome 3 configuration file

-- Include awesome library, with lots of useful function!
require("awful")
require("beautiful")
require("wicked")
require("naughty")
require("etree")

-- require("lua_mpd")
require("sqlite3")

-- You can overwrite to 'main_dir = os.getenv("HOME")'
main_dir = "/usr/src/examples/awesome-configs/uzsolt/"
-- This is a file path to a theme file which will defines colors.
theme_path = main_dir .. "/awesome-resources/themes/uzsolt"

-- External programs files
newsbeuter_db = os.getenv("HOME") .. "/.newsbeuter/cache.db"
taskcoach_db = os.getenv("HOME") .. "/Catalogs/taskcoach"

-- This is used later as the default terminal to run.
terminal = "roxterm"

modkey = "Mod1"
winkey = "Mod3"

-- Table of layouts to cover with awful.layout.inc, order matters.
layouts =
{
     awful.layout.suit.tile,
     awful.layout.suit.tile.left,
     awful.layout.suit.tile.bottom,
     awful.layout.suit.tile.top,
     awful.layout.suit.fair,
     awful.layout.suit.fair.horizontal,
     awful.layout.suit.max,
     awful.layout.suit.max.fullscreen,
     awful.layout.suit.magnifier,
     awful.layout.suit.floating
}

awesome_config_path = main_dir .. "/.config/awesome/" 
function dopath(file)
    dofile(awesome_config_path .. file)
end

dopath("tags.lua") 
dopath("client_rules.lua") 

-- Define if we want to use titlebar on all applications.
use_titlebar = false
-- }}}

-- {{{ Initialization
-- Initialize theme (colors).
beautiful.init(theme_path)

-- Register theme in awful.
-- This allows to not pass plenty of arguments to each function
-- to inform it about colors we want it to draw.
-- awful.beautiful.register(beautiful)


dopath("widgets.lua")
dopath("statusbars.lua")
dopath("keybindings.lua")
dopath("hooks.lua")

os.setlocale("hu_HU.UTF-8")

wicked.register(tb_date, wicked.widgets.date, '%Y. %b. %d., %a.  <span color="lightblue">%H:%M:%S</span>')
-- cpu usage
wicked.register(gr_cpu, wicked.widgets.cpu, '$1', 1, 'd_cpu')
wicked.register(tb_cpu, wicked.widgets.cpu, '$1%')

-- swap and memory
wicked.register(tb_mem, wicked.widgets.mem, '$1%')
wicked.register(tb_swap, wicked.widgets.swap, '$1%')

-- Set up some hooks
awful.hooks.focus.register(hook_focus)
awful.hooks.unfocus.register(hook_unfocus)
awful.hooks.marked.register(hook_marked)
awful.hooks.unmarked.register(hook_unmarked)
awful.hooks.manage.register(hook_manage)
awful.hooks.arrange.register(hook_arrange)
awful.hooks.timer.register(1, hook_uptime)
awful.hooks.timer.register(1, hook_moc)
awful.hooks.timer.register(5, hook_sensors)

-- hook_rss()
awful.hooks.timer.register(60, hook_rss)

-- hook_clawsmail
awful.hooks.timer.register(60, hook_clawsmail)

-- tv program
hook_fetch_rss()
hook_tvmusor()

awful.hooks.timer.register(10, hook_tvmusor)
awful.hooks.timer.register(60, hook_fetch_rss)
awful.hooks.timer.register(60, hook_taskcoach_reload)
awful.hooks.timer.register(10, hook_taskcoach_print)

-- network
wicked.register(tb_net_down,wicked.widgets.net, '${eth0 down_kb}kbs',nil,nil,0)
wicked.register(gr_net_in, wicked.widgets.net, '${eth0 down_kb}',1,'d_net_in',nil,nil,0)
wicked.register(tb_net_up, wicked.widgets.net, '${eth0 up_kb}kbs')
wicked.register(gr_net_out, wicked.widgets.net, '${eth0 up_kb}',1,'d_net_out')

